@@ -1,5 +1,5 @@
+from torchtrainer.trainingcallback import TrainingCallback
 from torchnet.meter import AverageValueMeter
-from trainingcallback import TrainingCallback
 
 class CalculateLossCallback(TrainingCallback):
 	def __init__(self, key):
