@@ -1,4 +1,4 @@
-from trainingcallback import TrainingCallback
+from torchtrainer.trainingcallback import TrainingCallback
 from torchtrainer.utils.epochsplotter import EpochsPlotter
 
 class PlotCallback(TrainingCallback):
