@@ -1,6 +1,6 @@
 import os
 import torch
-from trainingcallback import TrainingCallback
+from torchtrainer.trainingcallback import TrainingCallback
 from torchtrainer.trainer import Mode
 
 class SaveParametersCallback(TrainingCallback):
