@@ -1,4 +1,4 @@
-from trainingcallback import TrainingCallback
+from torchtrainer.trainingcallback import TrainingCallback
 
 class SetTQDMBarDescription(TrainingCallback):
 	def __init__(self, keys=["Loss", "Accuracy"]):
